#
# spec file for package deb (Version 1.15.5.2)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

%define debhelper_ver 7.4.8
%define devscripts_ver 2.10.58

Name:           deb
BuildRequires:  gcc-c++ ncurses-devel zlib-devel
%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
%endif
Url:            http://www.debian.org
License:        GPLv2+
Group:          System/Packages
PreReq:         /bin/touch
Provides:       dpkg dpkg-dev debhelper dselect dpkg-doc devscripts
Requires:       perl = %{perl_version}
Requires:       cpio patch make html2text
AutoReqProv:    on
Version:        1.15.5.2
Release:        5.1
Summary:        Tools for Debian Packages
Source:         dpkg_%{version}.tar.bz2
Source1:        debhelper_%{debhelper_ver}.tar.bz2
Source2:        devscripts_%{devscripts_ver}.tar.bz2
Source3:        sensible-editor
Patch0:         debhelper-no-localized-manpages.diff
Patch1:         devscripts-buildfix.diff
Patch2:         debhelper-pod2man-no-utf8.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} < 1120
%define _libexecdir /usr/lib
%endif

%if 0%{?suse_version}
BuildRequires:  sgmltool texlive-latex update-alternatives libbz2-devel
Requires:       update-alternatives
%if 0%{?suse_version} > 1100
BuildRequires:  libselinux-devel
%define use_selinux 1
%endif
%endif
%if 0%{?fedora_version}
BuildRequires:  libselinux-devel tetex-latex texinfo-tex linuxdoc-tools
%define use_selinux 1
%endif
%if 0%{?rhel_version}
BuildRequires:  libselinux-devel tetex-latex texinfo-tex linuxdoc-tools
%define use_selinux 1
%endif
%if 0%{?centos_version}
BuildRequires:  libselinux-devel tetex-latex texinfo-tex linuxdoc-tools
%define use_selinux 1
%endif

%description
This package contains tools for working with Debian packages. It makes
it possible to create and extract Debian packages. If Alien is
installed, the packages can be converted to RPMs.

This package contains the following Debian packages: dpkg, dselect,
dpkg-doc, dpkg-dev, debhelper, and devscripts.


%lang_package
%prep
%setup -q -n dpkg-%{version} -b 1 -b 2
pushd ..
%patch0
%if 0%{?suse_version} < 1130
%patch2
%endif
pushd devscripts-%{devscripts_ver}
%patch1 -p1
popd
popd
# update arch table
sed -n '/linux-gnu/ s/linux-gnu/suse-linux/p' debian/archtable > debian/archtable.tmp
cat debian/archtable.tmp >> debian/archtable
rm debian/archtable.tmp

%build
%{?suse_update_config:%{suse_update_config -f}}
export CFLAGS="$RPM_OPT_FLAGS"
%if 0%{?use_selinux}
export SELINUX_LIBS="-lselinux"
%endif
%configure\
%if 0%{?use_selinux}
	--with-selinux \
%endif
	--localstatedir=%{_localstatedir}/lib\
	--libdir=%{_prefix}/lib
# configure somehow does not detect architecture correctly in OBS (bnc#469337), so 
# let's do an awful hack and fix it in config.h
%ifarch x86_64
sed -i 's/^#define ARCHITECTURE ""/#define ARCHITECTURE "amd64"/' config.h
%endif
%ifarch %ix86
sed -i 's/^#define ARCHITECTURE ""/#define ARCHITECTURE "i386"/' config.h
%endif
%ifarch ppc powerpc
sed -i 's/^#define ARCHITECTURE ""/#define ARCHITECTURE "powerpc"/' config.h
%endif
%ifarch ppc64 powerpc64
sed -i 's/^#define ARCHITECTURE ""/#define ARCHITECTURE "ppc64"/' config.h
%endif
make %{?_smp_mflags}
# This makes debhelper man pages
cd ../debhelper
make %{?_smp_mflags} VERSION='%{debhelper_ver}'
##
# devscripts
##
# need dpkg-parsechangelog for devscripts
export PATH="$RPM_BUILD_DIR/dpkg-%{version}/scripts:$PATH"
export PERL5LIB="$RPM_BUILD_DIR/dpkg-%{version}/scripts"
cd ../devscripts-%{devscripts_ver}
make %{?_smp_mflags}

%install
#mkdir -p $RPM_BUILD_ROOT/usr/share
#ln -s $RPM_BUILD_ROOT/usr/share $RPM_BUILD_ROOT/share
##
# dpkg stuff
##
%__make DESTDIR=%{buildroot} install
# locales
%{find_lang} dpkg
%{find_lang} dselect
%{find_lang} dpkg-dev
cat dpkg.lang dselect.lang dpkg-dev.lang > %{name}.lang
# docs
install -d -m 755 $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
install -m 644 ABOUT-NLS $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
install -m 644 AUTHORS $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
install -m 644 COPYING $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
install -m 644 doc/triggers.txt $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
install -m 644 INSTALL $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
install -m 644 NEWS $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
install -m 644 README* $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
install -m 644 THANKS $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
install -m 644 TODO $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
install -m 644 debian/changelog $RPM_BUILD_ROOT/%{_docdir}/deb/dpkg
##
# debhelper stuff
##
cd ../debhelper
# autoscripts
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/debhelper/autoscripts
install -m 644 autoscripts/* $RPM_BUILD_ROOT%{_datadir}/debhelper/autoscripts
# perl modules:
install -d -m 755 $RPM_BUILD_ROOT%{perl_vendorlib}/Debian/Debhelper
install -d -m 755 $RPM_BUILD_ROOT%{perl_vendorlib}/Debian/Debhelper/Sequence
install -m 644 Debian/Debhelper/Sequence/*.pm $RPM_BUILD_ROOT%{perl_vendorlib}/Debian/Debhelper/Sequence
install -m 644 Debian/Debhelper/*.pm $RPM_BUILD_ROOT%{perl_vendorlib}/Debian/Debhelper
# docs:
install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/deb/debhelper/examples
install -m 644 examples/* $RPM_BUILD_ROOT%{_docdir}/deb/debhelper/examples
install -m 644 doc/* $RPM_BUILD_ROOT%{_docdir}/deb/debhelper
install -m 644 debian/{changelog,copyright} $RPM_BUILD_ROOT%{_docdir}/deb/debhelper
# man pages:
install -d -m 755 $RPM_BUILD_ROOT%{_mandir}/man1
install -d -m 755 $RPM_BUILD_ROOT%{_mandir}/man7
install -m 644 *.1 $RPM_BUILD_ROOT%{_mandir}/man1
install -m 644 debhelper.7 $RPM_BUILD_ROOT%{_mandir}/man7
# binaries:
install -d -m 755 $RPM_BUILD_ROOT%{_bindir}
install -m 755 dh_*[^1-9] $RPM_BUILD_ROOT%{_bindir}
##
# devscripts
##
cd ../devscripts-%{devscripts_ver}
make install DESTDIR=$RPM_BUILD_ROOT
##
# extras
##
install -m 755 %{SOURCE3} $RPM_BUILD_ROOT%{_bindir}
##
# remove update-alternatives stuff (included in separate package)
##
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/alternatives
rm -rf $RPM_BUILD_ROOT%{_localstatedir}/lib/dpkg/alternatives
rm -rf $RPM_BUILD_ROOT%{_bindir}/update-alternatives
rm -rf $RPM_BUILD_ROOT%{_sbindir}/update-alternatives
rm -rf $RPM_BUILD_ROOT%{_mandir}/man8/update-alternatives.8
rm -rf $RPM_BUILD_ROOT%{_mandir}/*/man8/update-alternatives.8
##
# remove duplicate files
##
%if 0%{?suse_version} > 1010
%fdupes %buildroot
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
cd %{_localstatedir}/lib/dpkg
for f in diversions statoverride status ; do
    [ ! -f $f ] && touch $f
done
exit 0

%if 0%{?suse_version} > 1010
%files lang -f %{name}.lang
%endif

%files
%defattr(-,root,root)
%doc %{_docdir}/deb
%doc %{_mandir}/man*/*
%dir %{_sysconfdir}/dpkg
%config(noreplace) %{_sysconfdir}/dpkg/*
%{_bindir}/*
%{_sbindir}/*
%{_prefix}/lib/dpkg
%{_datadir}/dpkg
%{_localstatedir}/lib/dpkg
%{_datadir}/debhelper
%{perl_vendorlib}/Debian
%{perl_vendorlib}/Dpkg
%{perl_vendorlib}/Dpkg.pm
%{_libexecdir}/devscripts
%{_datadir}/devscripts

%if 0%{?rhel_version} || 0%{?centos_version} || 0%{?fedora_version}
%{_datadir}/locale/ast/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/bs/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/bs/LC_MESSAGES/dselect.mo
%{_datadir}/locale/ca/LC_MESSAGES/dpkg-dev.mo
%{_datadir}/locale/ca/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/ca/LC_MESSAGES/dselect.mo
%{_datadir}/locale/cs/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/cs/LC_MESSAGES/dselect.mo
%{_datadir}/locale/da/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/da/LC_MESSAGES/dselect.mo
%{_datadir}/locale/de/LC_MESSAGES/dpkg-dev.mo
%{_datadir}/locale/de/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/de/LC_MESSAGES/dselect.mo
%{_datadir}/locale/dz/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/el/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/el/LC_MESSAGES/dselect.mo
%{_datadir}/locale/eo/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/es/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/es/LC_MESSAGES/dselect.mo
%{_datadir}/locale/et/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/et/LC_MESSAGES/dselect.mo
%{_datadir}/locale/eu/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/eu/LC_MESSAGES/dselect.mo
%{_datadir}/locale/fr/LC_MESSAGES/dpkg-dev.mo
%{_datadir}/locale/fr/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/fr/LC_MESSAGES/dselect.mo
%{_datadir}/locale/gl/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/gl/LC_MESSAGES/dselect.mo
%{_datadir}/locale/hu/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/hu/LC_MESSAGES/dselect.mo
%{_datadir}/locale/id/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/id/LC_MESSAGES/dselect.mo
%{_datadir}/locale/it/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/it/LC_MESSAGES/dselect.mo
%{_datadir}/locale/ja/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/ja/LC_MESSAGES/dselect.mo
%{_datadir}/locale/km/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/ko/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/ko/LC_MESSAGES/dselect.mo
%{_datadir}/locale/ku/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/lt/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/mr/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/nb/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/nb/LC_MESSAGES/dselect.mo
%{_datadir}/locale/ne/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/nl/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/nl/LC_MESSAGES/dselect.mo
%{_datadir}/locale/nn/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/nn/LC_MESSAGES/dselect.mo
%{_datadir}/locale/pa/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/pl/LC_MESSAGES/dpkg-dev.mo
%{_datadir}/locale/pl/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/pl/LC_MESSAGES/dselect.mo
%{_datadir}/locale/pt/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/pt/LC_MESSAGES/dselect.mo
%{_datadir}/locale/pt_BR/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/pt_BR/LC_MESSAGES/dselect.mo
%{_datadir}/locale/ro/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/ro/LC_MESSAGES/dselect.mo
%{_datadir}/locale/ru/LC_MESSAGES/dpkg-dev.mo
%{_datadir}/locale/ru/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/ru/LC_MESSAGES/dselect.mo
%{_datadir}/locale/sk/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/sk/LC_MESSAGES/dselect.mo
%{_datadir}/locale/sv/LC_MESSAGES/dpkg-dev.mo
%{_datadir}/locale/sv/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/sv/LC_MESSAGES/dselect.mo
%{_datadir}/locale/th/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/tl/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/tl/LC_MESSAGES/dselect.mo
%{_datadir}/locale/vi/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/vi/LC_MESSAGES/dselect.mo
%{_datadir}/locale/zh_CN/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/zh_CN/LC_MESSAGES/dselect.mo
%{_datadir}/locale/zh_TW/LC_MESSAGES/dpkg.mo
%{_datadir}/locale/zh_TW/LC_MESSAGES/dselect.mo
%endif
%changelog
* Wed Jan  6 2010 jengelh@medozas.de
- enable parallel building with smp_mflags
* Fri Dec 18 2009 wr@rosenauer.org
- try to fix older dists
* Wed Nov 25 2009 puzel@novell.com
- update to dpkg-1.15.5.2, debhelper-7.4.8, devscripts-2.10.58
  - huge number of changelogs - please see appropriate changelogs
  for details:
  - /usr/share/doc/packages/deb/debhelper/changelog
  - /usr/share/doc/packages/deb/dpkg/changelog
* Thu Nov 12 2009 wr@rosenauer.org
- include devscripts-2.10.55
- add sensible-editor helper script
* Thu Aug 13 2009 puzel@novell.com
- update to debhelper-7.3.12
  * dh: Allow creation of new sequences (such as to handle a patch
    target for quilt), by adding an add_command function to the
    sequence addon interface.
  * perl_build: Fix Build check to honor source directory setting.
  * perl_build: Avoid failing if forced to be used in dh_auto_clean
    when Build does not exist (ie due to being run twice in a row).
  * dh_builddeb: Fix man page typo.
  * dh_installdeb: In udeb mode, support the menutest and isinstallable
    maintainer scripts.
* Tue Aug  4 2009 puzel@novell.com
- update to debhelper-7.3.9
  * cmake: Avoid forcing rpath off as this can break some test suites.
    It gets stripped by cmake at install time.
* Mon Jul 27 2009 puzel@novell.com
- update to debhelper-7.3.8
  * First upload of buildsystems support to unstable.
    Summary: Adds --buildsystem (modular, OO buildsystem classes),
  - -sourcedirectory, --builddirectory, and support for cmake
    and ant.
  * python_distutils buildsystem: Build for all supported Python
    versions that are installed. Ensure that correct shebangs are
    created by using `python' first during build and install.
    Also build with python*-dbg if the package build-depends
    on them.
* Thu Jul 16 2009 puzel@novell.com
- update to debhelper-7.3.4
  * Add a versioned dep on perl-base, to get a version that supports
    GetOptionsFromArray.
  * dh_install: Fix support for the case where --sourcedir=debian/tmp/foo
    is used. Perl was not being greedy enough and the 'foo' was not stripped
    from the destination directory in this unusual case.
  * dh_install: Fix support for the case where debian/tmp is
    explicitly specified in filename paths despite being searched by
    default.
  * dh_install: Add test suite covering the last 5 bugs.
* Fri Jul  3 2009 puzel@novell.com
- update to debhelper-7.3.1
  * Modular object oriented dh_auto_* buildsystem support,
    contributed by Modestas Vainius
  - dh_auto_* --sourcedirectory can now be used to specify a source
    directory if sources and/or the whole buildsystem lives elsewhere
    than the top level directory.
  - dh_auto_* --builddirectory can now be used to specify a build
    directory to use for out of source building, for build systems
    that support it.
  - dh_auto_* --buildsystem can now be used to override the autodetected
    build system, or force use of a third-party class.
  - dh_auto_* --list can be used to list available and selected build
    systems.
  - Adds support for cmake.
  - For the perl_build build system, Build is used consistently
    instead of falling back to using the generated Makefile.
  - Historical dh_auto_* behavior should be preserved despite these
    large changes..
  * Move two more command-specific options to only be accepted by the commands
    that use them. The options are:
  - -sourcedir, --destdir
    If any third-party debhelper commands use either of the above options,
    they will be broken, and need to be changed to pass options to init().
  * Make dh not complain about unknown, command-specific options passed to it,
    and further suppress warnings about such options it passes on to debhelper
    commands. This was attempted incompletely before in version 7.2.17.
  * dh_install: Fix installation of entire top-level directory
    from debian/tmp.
  * dh_install: Handle correctly the case where a glob expands to
    a dangling symlink, installing the dangling link as requested.
  * dh_install: Fix fallback use of debian/tmp in v7 mode; a bug caused
    it to put files inside a debian/tmp directory in the package build
    directory, now that prefix is stripped.
  * dh_shlibdeps: Ensure DEBIAN directory exists, as dpkg-shlibdeps
    prints a confusing warning if it does not.
  * dh_auto_install: Pass --install-layout=deb to setup.py
    to support python 2.6.
  * Allow command-specific options to be passed to commands
    via dh without causing other commands to emit a getopt
    warning or deprecation message.
  * dh_installinfo: No longer inserts install-info calls into
    maintainer scripts, as that is now triggerized. Adds a dependency
    via misc:Depends to handle partial upgrades. Note that while
    dh_installinfo already required that info files had a INFO-DIR-SECTION,
    the new system also requires they have START-INFO-DIR-ENTRY and
    END-INFO-DIR-ENTRY for proper registration. I assume there will be
    some mass bug filing for any packages that do not have that.
* Fri Jun 12 2009 puzel@suse.cz
- update to debhelper-7.2.16
  * dh_gconf: Add missed half of postrm fragment removal.
* Thu Jun 11 2009 puzel@suse.cz
- update to debhelper-7.2.15
  * dh_strip, dh_shlibdeps: Add support for OCaml shared libraries.
  * dh_compress: Avoid compressing .svg and .sgvz files, since these
    might be used as images on a html page, and also to avoid needing
    to special case the .svgz extension when compressing svg.
  * dh_scrollkeeper: Now a deprecated no-op.
  * dh_gconf: Remove postrm fragment that handled schema migration
    from /etc to /usr.
* Thu May 21 2009 puzel@suse.cz
- update to debhelper-7.2.14
  * dh: Avoid writing log after override_dh_clean is run.
  * dh_auto_configure: Pass --skipdeps safely via PERL_AUTOINSTALL.
  * dh_auto_configure: Revert --skipdeps change
* Wed May 13 2009 puzel@suse.cz
- update to debhelper-7.2.11
  * dh: Support --with addon,addon,...
  * dh_auto_configure: Add --skipdeps when running Makefile.PL,
    to prevent Module::Install from trying to download dependencies.
  * Support debian/foo.os files to suppliment previous debian/foo.arch
    file support.
* Mon May 11 2009 puzel@suse.cz
- update to debhelper-7.2.10
  * Close COMPAT_IN filehandle.
  * dh_auto_configure: Clarify man page re adding configure
    parameters.
  * dh_auto_configure: Pass packlist=0 when running Makefile.PL,
    in case it is a Build.PL passthru, to avoid it creating
    the .packlist file.
* Wed May  6 2009 puzel@suse.cz
- update to debhelper-7.2.9
  * dh_fixperms: Ensure lintian overrides are mode 644.
  * dh_fixperms: Fix permissions of OCaml .cmxs files.
  * dh: Add --without to allow disabling sequence addons (particularly
    useful to disable the default python-support addon).
- split -lang subpackage
* Tue Apr 21 2009 puzel@suse.cz
- update to debhelper-7.2.8
  * dh_desktop: Now a deprecated no-op, since desktop-file-utils
    uses triggers.
  * Move dh sequence documentation to PROGRAMMING.
* Thu Apr 16 2009 puzel@suse.cz
- update to debhelper-7.2.7
  * fix calling the same helper for separate packages in the override of dh
    binary-indep/binary-arch
  * add --remaining-packages option
  * dh_icons: ignore gnome and hicolor themes (will be handled
    by triggers)
* Mon Apr  6 2009 puzel@suse.cz
- add a hack to detect architecture correctly (bnc#469337)
* Mon Mar 16 2009 puzel@suse.cz
- update to debhelper-7.2.6
  * examples files updated to add dh_bugfiles, remove obsolete
    dh_python
  * dh_auto_test: Support DEB_BUILD_OPTIONS=nocheck
  * set MODULEBUILDRC=/dev/null when running perl Build scripts
    to avoid ~/.modulebuildrc influencing the build
  * dh_installmenus: Revert removal of update-menus calls
* Mon Mar  9 2009 puzel@suse.cz
- update to debhelper-7.2.4
  * dh_makeshlibs: Fix --add-udeb, for real
  * dh_installmenus: Now that a triggers capable menu and dpkg are in
    stable, menu does not need to be explicitly run in maintainer
    scripts, except for packages with menu-methods files.
  * dh_installdocs: No longer add maintainer script code to call
    doc-base, as it supports triggers in stable.
  * dh_bugfiles: New program, contributed by Modestas Vainius.
  * dh: Override LC_ALL, not LANG.
  * dh_installchangelogs: Support -X to exclude automatic installation
    of specific upstream changelogs.
  * Compat level 4 is now deprecated.
  * dh_makeshlibs: Re-add --add-udeb support.
  * dh_shlibdeps: Remove --add-udeb switch (was accidentially added here).
* Thu Mar  5 2009 puzel@suse.cz
- update to debhelper-7.2.2
  * dh_installmodules: Give files in /etc/modprobe.d a .conf
    syntax, as required by new module-init-tools.
  * dh_installmodules: Add preinst and postinst code to handle
    cleanly renaming the modprobe.d files on upgrade.
  * Two updates to conffile moving code from wiki:
  - Support case where the conffile name is a substring of another
    conffile's name.
  - Support case where dpkg-query says the file is obsolete.
* Tue Mar  3 2009 puzel@suse.cz
- update to dpkg-1.15.0 and debhelper-7.2.1
  - huge number of changes, please see
    /usr/share/doc/packages/deb/dpkg/changelog and
  /usr/share/doc/packages/deb/debhelper/changelog
  for details
* Tue Jan 20 2009 puzel@suse.cz
- partially revert change from Aug 12 2008 (bnc#467332)
* Thu Dec 18 2008 puzel@suse.cz
- update debhelper to 7.1.1
  * dh_install(1): Order options alphabetically.
  * Fix some docs that refered to --srcdir rather than --sourcedir.
  * Add Vcs-Browser field.
  * Ignore unknown options in DH_OPTIONS.
* Wed Oct 29 2008 puzel@suse.cz
- update debhelper to 7.1.0
  * dh_installchangelogs: Fall back to looking for changelog files ending
    with ".txt".
  * dh_gencontrol: Ensure misc:Depends is set in substvars to avoid dpkg
    complaining about it when it's empty.
  * dh: Fix typo in example.
  * Allow individual debhelper programs to define their own special options
    by passing a hash to init(), which is later passed on the Getopt::Long.
  * Move many command-specific options to only be accepted by the command
    that uses them. Affected options are:
  - x, -r, -R, -l, -L, -m,
  - -include-conffiles, --no-restart-on-upgrade, --no-start,
  - -restart-after-upgrade, --init-script, --filename, --flavor, --autodest,
  - -libpackage, --add-udeb, --dpkg-shlibdeps-params,
  - -dpkg-gencontrol-params, --update-rcd-params, --major, --remove-d,
  - -dirs-only, --keep-debug, --version-info, --list-missing, --fail-missing,
  - -language, --until, --after, --before, --remaining, --with
  * If any third-party debhelper commands use any of the above options,
    they will be broken, and need to be changed to pass options to init().
  * To avoid breaking rules files that pass options to commands that do not
    use them, debhelper will now only warn if it encounters an unknown
    option. This will be converted back to an error later.
* Tue Sep 16 2008 mrueckert@suse.de
- do not package update-alternatives it conflicts with the required
  package update-alternatives
* Tue Sep  2 2008 prusnak@suse.cz
- updated to 1.14.21
  * lots of fixes - see ChangeLog
- enabled SELinux support [Fate#303662]
* Mon Sep  1 2008 puzel@suse.cz
- update debhelper to 7.0.17
  * dh_auto_install: Fix man page, was referring to dh_auto_clean.
  * dh_gencontrol: Drop the Homepage field from udebs. Closes debian bug #492719
  * Typo. Closes debian bug #493062
  * dh_auto_install: Improve check for MakeMaker, to avoid passing PREFIX
    if the Makefile was generated by Module::Build::Compat. Closes debian bug #496157
* Tue Aug 12 2008 puzel@suse.cz
- fix paths
  * install perl stuff to %%{perl_vendorlib}/Debian where it is
    expected by alien
* Mon Aug 11 2008 coolo@suse.de
- fix paths
* Mon Jul 21 2008 puzel@suse.cz
- update debhelper to 7.0.16
  * dh: Avoid passing --with on to subcommands. Closes debian bug #490886
  * dh_installchangelogs: When searching for changelog in v7 mode, skip
    empty files. Closes debian bug #490937
* Fri Jul 18 2008 puzel@suse.cz
- update debhelper to 7.0.15
  * dh_clean: Do not delete *-stamp files in -k mode in v7. Closes debian bug #489918
* Tue Jul  8 2008 puzel@suse.cz
- update debhelper to 7.0.14
  * load python-support sequence file first, to allow ones loaded later to disable it
* Mon Jul  7 2008 puzel@suse.cz
- update dpkg to 1.14.19
  * a lot of changes and bugfixes
  * for complete changelog see program sources or
    /usr/share/doc/packages/deb/dpkg/changelog
  * removed dpkg-gcc4.patch - compiles fine without it
  * removed dpkg-make.patch, dpkg-automake.diff, dpkg-strip.patch
  * not needed anymore because of heavy changes in the build system
  * removed dpkg_1.10.23-doc.patch - fixed in upstream
- update debhelper to 7.0.13
  * a lot of changes and bugfixes
  * for complete changelog see program sources or
    /usr/share/doc/packages/deb/debhelper/changelog
  * debhelper-no-localized-manpages.diff - do not use po4a to generate
    localized documentation
- dpkg is now built by configure/make
- debhelper is now built by make
* Thu Jul 26 2007 dmueller@suse.de
- remove config.guess dependency completely
* Tue Jul 24 2007 dmueller@suse.de
- link the config.guess from automake
* Sun Apr 22 2007 ro@suse.de
- use texlive for building
* Fri Mar 30 2007 aj@suse.de
- Adjust BuildRequires.
* Fri Aug 18 2006 aj@suse.de
- Fix build with new make.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 schwab@suse.de
- Don't strip binaries.
* Wed Dec 21 2005 ro@suse.de
- remove unpackaged symlinks
* Thu Sep  8 2005 mjancar@suse.cz
- package missing dpkg-{architecture,scanpackages,scansources} (#106239)
* Thu May 12 2005 meissner@suse.de
- use RPM_OPT_FLAGS
* Fri Apr  8 2005 uli@suse.de
- fixed to build with GCC4
* Thu Feb 10 2005 rengelhard@suse.de
- update dpkg to 1.10.27 (just translation updates)
* Thu Jan 20 2005 ro@suse.de
- update dependency: html2txt -> html2text
* Wed Jan 12 2005 rengelha@suse.de
- update dpkg to 1.10.26
* Wed Jan  5 2005 rengelhard@suse.de
- update debhelper to 4.2.30
* Tue Jan  4 2005 rengelhard@suse.de
- update debhelper to 4.2.29
* Wed Dec 15 2004 rengelhard@suse.de
- update debhelper to 4.2.28
* Mon Dec 13 2004 rengelhard@suse.de
- update debhelper to 4.2.27
* Tue Nov 16 2004 rengelhard@suse.de
- update dpkg to 1.10.25
* Thu Nov 11 2004 rengelhard@suse.de
- update debhelper to 4.2.24
* Fri Oct 29 2004 rengelhard@suse.de
- update debhelper to 4.2.23
* Wed Oct 27 2004 rengelhard@suse.de
- update dpkg to 1.10.24
* Wed Oct 13 2004 rengelhard@suse.de
- update debhelper to 4.2.21
* Tue Sep  7 2004 ro@suse.de
- remove stuff now present in own update-alternatives package
* Thu Aug 19 2004 mcihar@suse.cz
- update debhelper to 4.2.19
- update dpkg to 1.10.23
- use sed rather than patches
- remove patches accepted in upstream
* Mon May 31 2004 mcihar@suse.cz
- update debhelper to 4.2.10
- update dpkg to 1.10.21
* Thu Mar  4 2004 mcihar@suse.cz
- no root for build
- revert to manual debhelper installation as installation using
  debhelper needs dpkg and debhelper installed
* Wed Mar  3 2004 mcihar@suse.cz
- debhelper has debian/control file, so do not install manually
- update debhelper to 4.2.4
- update dpkg to 1.10.18.1
* Tue Jan 27 2004 ro@suse.de
- debhelper has no debian/control file, so install manually
* Tue Jan 27 2004 mcihar@suse.cz
- install debhelper man pages on correct place
* Mon Jan 26 2004 mcihar@suse.cz
- updated debhelper to 4.1.88 and dpkg to 1.10.18
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Aug  7 2003 mcihar@suse.cz
- updated debhelper to 4.1.57
* Mon Jul 28 2003 schwab@suse.de
- Fix format string.
- Fix undefined use of longjmp.
- Use perl_vendorlib.
* Wed Jun 18 2003 mcihar@suse.cz
- updated debhelper to 4.1.47 (mostly fixes in dh_python)
- included directories for translated man pages
- use find_lang
* Tue May 13 2003 mcihar@suse.cz
- updated debhelper to 4.1.43
- updated dpkg to 1.1.10
* Tue Apr  8 2003 mcihar@suse.cz
- updated debhelper to 4.1.40
- fixed problems with new coreutils
* Thu Mar  6 2003 mcihar@suse.cz
- configuration files under /etc marked as %%config
* Thu Jan 30 2003 mcihar@suse.cz
- updated debhelper to 4.1.29:
  * Added a dh_python command.
  * Various fixes.
* Wed Nov 13 2002 mcihar@suse.cz
- updated dpkg to 1.10.9, major changes:
  * Make the multiline regex have an upper bound, instead of being
    unbounded, as newer perls have a larger stack frame, which cause them
    to segfault quicker with larger inputs.
  * Fix segfault in md5sum if the file being checked doesn't exist.
  * Fix extraction of md5sum in dpkg-scanpackages.
  * Handle directories better in md5sum.
  * Fix several read pass buffer bugs, and a memleak.
  * Fix segfault when --auto-deconfigure is given.
- updated debhelper to 4.1.20, major changes:
  * typo in dh_shlibdeps(1)
  * dh_fixperms: Make sure .pm files are 0644.
  * dh_strip: detect and don't strip debug/*.so files.
  * Various improvements to debhelper(1).
  * Clarified dh_perl man page.
  * Fixed excessive escaping around terms in DH_EXCLUDE_FIND.
  * Patch from Andrew Suffield to make dh_perl understand #!/usr/bin/env perl
- included part of postinst script from debian package
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <sp> to <opensp>
- changed neededforbuild <sp-devel> to <>
* Wed Aug 28 2002 mcihar@suse.cz
- corrected requires
* Wed Aug  7 2002 mcihar@suse.cz
- updated to debhelper 4.1.3:
  * various bugfixes
  * removed /usr/doc manglement code from postinst and prerm
  * removed dh_installxaw
  * dh_installchangelogs installs debian/NEWS
- updated to dpkg 1.10.4:
  * plenty of bugfixes and new switches
  * added Large File Summit extension
  * added manpages for dpkg.cfg and dselect.cfg
  * updated translations
  * install archtable into /usr/share/dpkg/
- dpkg is now build by debian/rules not by script in spec
- removed md5sum.1 start-stop-daemon.8 install-info.8 manpages also
  for other locales (these programs are not installed)
* Tue Jun 11 2002 mcihar@suse.cz
- updated to debhelper 4.0.11 and dpkg 1.9.21
* Mon Aug 13 2001 ro@suse.de
- changed neededforbuild <sp_libs> to <sp-devel>
* Fri Jun  8 2001 cihlar@suse.cz
- fixed to compile with new autoconf
* Tue Apr 24 2001 cihlar@suse.cz
- fixed warnings on ia64
* Wed Apr 18 2001 cihlar@suse.cz
- fixed to compile
* Mon Mar  5 2001 cihlar@suse.cz
- dpkg updated to version 1.8.3.1
- debhelper updated to version 3.0.8
* Tue Dec  5 2000 schwab@suse.de
- Fix broken declaration.
* Tue Oct 31 2000 cihlar@suse.cz
- update to version 1.6.14
- bzipped sources
* Tue May 23 2000 cihlar@suse.cz
- added files in /etc and /var to %%files
* Mon May 22 2000 cihlar@suse.cz
- removed install-info and start-stop-daemon
* Mon May 15 2000 schwab@suse.de
- Fixed for ia64.
* Wed May  3 2000 cihlar@suse.cz
- package created - version 1.4.0.35 (debhelper 1.1.24)
